@@ -526,6 +526,7 @@ def main_impl():
         raise e
     delete_private_key_file(config)
 
+
 class SnowflakeSourceConnector(C8Connector):
     """SnowflakeSourceConnector's C8Connector impl."""
 
@@ -724,12 +725,12 @@ class SnowflakeSourceConnector(C8Connector):
                 'account': integration['account'],
                 'dbname': integration['dbname'],
                 'user': integration['user'],
-                'password': integration['password'],
                 'warehouse': integration['warehouse'],
                 'table': integration['table'],
                 # Optional config keys
                 'primary_key': integration.get('primary_key'),
                 'role': integration.get('role'),
+                'password': integration.get('password'),
                 'private_key_path': integration.get('private_key_path'),
                 'private_key_passphrase': integration.get('private_key_passphrase'),
                 'insecure_mode': integration.get('insecure_mode', False),
